@@ -27,7 +27,8 @@
 #' no structural value is chosen and a standard model for the effects is run.
 #' @param sc Structural value to be found in the cost variables defined in \code{data}. If set to \code{NULL}, 
 #' no structural value is chosen and a standard model for the costs is run.
-#' @param dist_e Distribution assumed for the effects. Current available chocies are: Normal ('norm') or Beta ('beta').
+#' @param dist_e Distribution assumed for the effects. Current available chocies are: Normal ('norm'), Beta ('beta'), Gamma ('gamma'), Exponential ('exp'),
+#' Weibull ('weibull'), Logistic ('logis'), Poisson ('pois'), Negative Binomial ('nbinom') or Bernoulli ('bern').
 #' @param dist_c Distribution assumed for the costs. Current available chocies are: Normal ('norm'), Gamma ('gamma') or LogNormal ('lnorm').
 #' @param type Type of structural value mechanism assumed. Choices are Structural Completely At Random (SCAR),
 #' and Structural At Random (SAR).
@@ -211,10 +212,15 @@ hurdle <- function(data, model.eff, model.cost, model.se = se ~ 1, model.sc = sc
   dist_e <- tolower(dist_e)
   dist_c <- tolower(dist_c)
   if(dist_e == "normal") { dist_e <- "norm" }
+  if(dist_e == "exponential") { dist_e <- "exp" }
+  if(dist_e == "logistic") { dist_e <- "logis" }
+  if(dist_e == "bernoulli") { dist_e <- "bern" }
+  if(dist_e == "poisson") { dist_e <- "pois" }
+  if(dist_e == "negative binomial") { dist_e <- "nbinom" }
   if(dist_c == "normal") { dist_c <- "norm" }
   if(dist_c == "lognormal") { dist_c <- "lnorm" }
-  if(!dist_e %in% c("norm", "beta") | !dist_c %in% c("norm", "gamma", "lnorm")) {
-    stop("Distributions available for use are 'norm' or 'beta' for the effects and 'norm', 'gamma', 'lnorm' for the costs")
+  if(!dist_e %in% c("norm", "beta", "exp", "weibull", "logis", "bern", "pois", "nbinom", "gamma") | !dist_c %in% c("norm", "gamma", "lnorm")) {
+    stop("Distributions available for use are 'norm', 'beta', 'gamma', 'logis', 'exp', 'weibull', 'nbinom', 'pois', 'bern'  for the effects and 'norm', 'gamma', 'lnorm' for the costs")
   }
   type <- toupper(type)
   if(!type %in% c("SCAR", "SAR")) {
