@@ -24,7 +24,8 @@
 #' @param model.mc A formula expression in conventional \code{R} linear modelling syntax. The response must be indicated with the 
 #' term 'mc'(missing costs) and any covariates must be provided on the right-hand side of the formula. 
 #' If there are no covariates, \code{1} should be specified on the right hand side of the formula. By default, covariates are placed on the "probability" parameter for the missing costs through a logistic-linear model.
-#' @param dist_e Distribution assumed for the effects. Current available chocies are: Normal ('norm') or Beta ('beta').
+#' @param dist_e Distribution assumed for the effects. Current available chocies are: Normal ('norm'), Beta ('beta'), Gamma ('gamma'), Exponential ('exp'),
+#' Weibull ('weibull'), Logistic ('logis'), Poisson ('pois'), Negative Binomial ('nbinom') or Bernoulli ('bern').
 #' @param dist_c Distribution assumed for the costs. Current available chocies are: Normal ('norm'), Gamma ('gamma') or LogNormal ('lnorm').
 #' @param type Type of missingness mechanism assumed. Choices are Missing At Random (MAR) and Missing Not At Random (MNAR).
 #' @param prob A numeric vector of probabilities within the range (0,1), representing the upper and lower
@@ -203,10 +204,15 @@ selection <- function(data, model.eff, model.cost, model.me = me ~ 1, model.mc =
   dist_e <- tolower(dist_e)
   dist_c <- tolower(dist_c)
   if(dist_e == "normal") { dist_e <- "norm" }
+  if(dist_e == "exponential") { dist_e <- "exp" }
+  if(dist_e == "logistic") { dist_e <- "logis" }
+  if(dist_e == "bernoulli") { dist_e <- "bern" }
+  if(dist_e == "poisson") { dist_e <- "pois" }
+  if(dist_e == "negative binomial") { dist_e <- "nbinom" }
   if(dist_c == "normal") { dist_c <- "norm" }
   if(dist_c == "lognormal") { dist_c <- "lnorm" }
-  if(!dist_e %in% c("norm", "beta") | !dist_c %in% c("norm", "gamma", "lnorm")) {
-    stop("Distributions available for use are 'norm', 'beta' for the effects and 'norm', 'gamma', 'lnorm' for the costs")
+  if(!dist_e %in% c("norm", "beta", "exp", "weibull", "logis", "bern", "pois", "nbinom", "gamma") | !dist_c %in% c("norm", "gamma", "lnorm")) {
+    stop("Distributions available for use are 'norm', 'beta', 'gamma', 'logis', 'exp', 'weibull', 'nbinom', 'pois', 'bern'  for the effects and 'norm', 'gamma', 'lnorm' for the costs")
   }
   type <- toupper(type)
   if(!type %in% c("MAR", "MNAR")) {
